@@ -35,105 +35,80 @@ Dmake "make" tool
 
 =item *
 
-L<Updates for many toolchain modules>
+Every bundled and dual-life modules upgraded to the latest version.
 
 =item *
 
-L<Bundle::CPAN> (including Perl modules that eliminate the need for
-external helper programs like C<gzip> and C<tar>)
+L<Bundle::CPAN>, L<Bundle::LWP> and L<CPAN::SQLite> to enhance the
+functionality of the CPAN client.
 
 =item *
 
-L<Bundle::LWP> (providing more reliable http CPAN repository support)
+Additional Perl modules that enhance the stability of core Perl for
+the Win32 platform
 
 =item *
 
-Additional Perl modules that enhance the stability of core Perl for the
-Win32 platform
+Modules that enhance the ability to install non-CPAN packages such as
+L<PAR::Dist>, L<PPM> and L<pip>.
 
 =item *
 
-Other modules that improve the toolchain, or enhance the ability to
-install packages.
+Prebuilt and known-good C libraries for math, crypto and XML support.
+
+=item *
+
+B<BETA> - Additions that provide L<Portable> support.
 
 =back
 
-The B<Perl::Dist::Strawberry> modules on CPAN contains programs and
-instructions for downloading component sources and assembling them into the
-executable installer for Strawberry Perl.  It B<does not> include the
-resulting Strawberry Perl installer.  
+The B<Perl::Dist::Strawberry> module available on CPAN contains the modules
+and L<perldist_strawberry> script that are used to generate the
+Strawberry Perl installers.
 
-See the Strawberry Perl website at L<http://strawberryperl.com/> to download
-the Strawberry Perl installer.
+Please note that B<Perl::Dist::Strawberry> B<does not> include the
+resulting Strawberry Perl installer. See the Strawberry Perl website at
+L<http://strawberryperl.com/> to download the Strawberry Perl installer.
 
-See L<Perl::Dist::Build> at L<http://search.cpan.org> for details on 
-the builder used to create Strawberry Perl from source.
+See L<Perl::Dist::Inno> for details on how the underlying distribution
+construction toolkit works.
 
 =head1 CHANGES FROM CORE PERL
 
-Strawberry Perl is and will continue to be based on the latest "stable" release
-of Perl, currently version 5.8.8.  Some additional modifications are included
-that improve general compatibility with the Win32 platform or improve
-"turnkey" operation on Win32.  
+Strawberry Perl is and will continue to be based on the latest "stable"
+releases of Perl, currently 5.8.8 and 5.10.0.
+
+Some additional modifications are included that improve general
+compatibility with the Win32 platform or improve "turnkey" operation on
+Win32.
 
 Whenever possible, these modifications will be made only by preinstalling
-additional CPAN modules within Strawberry Perl, particularly modules that have
-been newly included as core Perl modules in the "development" branch of perl
-to address Win32 compatibility issues.
+additional or updated CPAN modules within Strawberry Perl, particularly
+modules that have been newly included as core Perl modules in the
+"development" branch of perl to address Win32 compatibility issues.
 
-Modules or distributions currently included are:
+Additionally, a stub CPAN Config.pm file is added.  This provides a
+complete zero-conf preconfiguration for CPAN, using a stable
+L<http://cpan.strawberryperl.com/> redirector to bounce to a
+known-reliable mirrors.
 
-=over
+A more-thorough network-aware zero-conf capability is currently being
+developed and will be included at a later time.
 
-=item *
-
-ExtUtils::MakeMaker 6.30_01 -- fixes a Win32 perl path bug
-
-=item *
-
-CPAN 1.87_57 -- many small fixes for numerous annoyances on Win32
-
-=item * 
-
-Win32API::File -- to allow for deletion of in-use files at next reboot;
-required for CPAN.pm to be able to upgrade itself
-
-=item *
-
-IO -- to address Win32 Socket bugs
-    
-=item *
-
-Compress::Zlib, IO::Zlib and Archive::Tar -- to eliminate the CPAN.pm
-dependency on external, binary programs to handle .tar.gz files
-
-=item *
-
-Archive::Zip (and its dependency, Time::Local) -- to eliminate the CPAN.pm
-dependency on external, binary programs to handle .zip files
-
-=item *
-
-libnet -- provides Net::FTP to eliminate the CPAN.pm dependency on an external,
-binary ftp program; installed configured for FTP passive mode
-
-=back
-
-Additionally, a stub CPAN Config.pm file is installed.  It provides defaults
-to the path for dmake, to automatically follow dependencies and to use the
-Windows temporary directory for the CPAN working directory. 
+Strawberry has B<never> patched the Perl source code or modified the
+perl.exe binary.
 
 =head1 CONFIGURATION
 
 At present, Strawberry Perl must be installed in C:\strawberry.  The
 executable installer adds the following environment variable changes:
 
-    * adds directories to PATH
-        - C:\strawberry\perl\bin  
-        - C:\strawberry\c\bin  
+  * Adds directories to PATH
+    - C:\strawberry\perl\bin  
+    - C:\strawberry\c\bin  
 
 Users installing Strawberry Perl without the installer will need to
-change the environment manually.
+add the environment entries manually.
 
 =head1 METHODS
 
@@ -146,12 +121,14 @@ core.
 
 use 5.006;
 use strict;
-use Perl::Dist ();
+use URI::file                   ();
+use Perl::Dist                  ();
+use Perl::Dist::Machine         ();
 use Perl::Dist::Util::Toolchain ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.04';
+	$VERSION = '1.07';
 	@ISA     = 'Perl::Dist';
 }
 
@@ -163,10 +140,66 @@ use Object::Tiny qw{
 
 
 
+#####################################################################
+# Build Machine Generator
+
+=pod
+
+=head2 default_machine
+
+  Perl::Dist::Strawberry->default_machine->run;
+  
+The C<default_machine> class method is used to setup the most common
+machine for building Strawberry Perl.
+
+The machine provided creates a standard 5.8.8 distribution (.zip and .exe),
+a standard 5.10.0 distribution (.zip and .exe) and a Portable-enabled
+5.10.0 distribution (.zip only).
+
+Returns a L<Perl::Dist::Machine> object.
+
+=cut
+
+sub default_machine {
+	my $class = shift;
+
+	# Create the machine
+	my $machine = Perl::Dist::Machine->new( class => $class, @_ );
+
+	# Set the different versions
+	$machine->add_dimension('version');
+	$machine->add_option('version',
+		perl_version => '5100',
+	);
+	$machine->add_option('version',
+		perl_version => '588',
+	);
+	$machine->add_option('version',
+		perl_version => '5100',
+		portable     => 1,
+	);
+
+	# Set the different paths
+	$machine->add_dimension('drive');
+	$machine->add_option('drive',
+		image_dir => 'C:\strawberry',
+	);
+	$machine->add_option('drive',
+		image_dir => 'D:\strawberry',
+		zip       => 0,
+	);
+
+	return $machine;
+}
+
+
+
+
+
 #####################################################################
 # Configuration
 
-# Apply some default paths
+# Apply default paths
 sub new {
 	shift->SUPER::new(
 		app_id            => 'strawberryperl',
@@ -190,17 +223,19 @@ sub app_ver_name {
 	$_[0]->app_name
 		. ($_[0]->portable ? ' Portable' : '')
 		. ' ' . $_[0]->perl_version_human
-		. '.2';
+		. '.3 Beta 1';
 }
 
-# Lazily default the file name
+# Lazily default the file name.
 # Supports building multiple versions of Perl.
 sub output_base_filename {
 	$_[0]->{output_base_filename} or
 	'strawberry-perl'
-		. ($_[0]->portable ? '-portable' : '')
 		. '-' . $_[0]->perl_version_human
-		. '.2';
+		. '.3'
+		. ($_[0]->image_dir =~ /^d:/i ? '-ddrive' : '')
+		. ($_[0]->portable ? '-portable' : '')
+		. ($_[0]->portable ? '-beta-1' : '')
 }
 
 
@@ -244,36 +279,50 @@ sub install_c_libraries {
 #####################################################################
 # Customisations for Perl assets
 
-sub install_perl_588 {
-	my $self = shift;
-	$self->SUPER::install_perl_588(@_);
+sub patch_include_path {
+	my $self  = shift;
 
-	# Install the Strawberry CPAN::Config
-	$self->install_file(
-		share      => 'Perl-Dist-Strawberry CPAN_Config_588.pm',
-		install_to => 'perl/lib/CPAN/Config.pm',
-	);
+	# Find the share path for this distribution
+	my $share = File::ShareDir::dist_dir('Perl-Dist-Strawberry');
+	my $path  = File::Spec->catdir( $share, 'strawberry' );
+	unless ( -d $path ) {
+		die("Directory $path does not exist");
+	}
 
-	return 1;
+	# Prepend to the default include path
+	return [ $path,
+		@{ $self->SUPER::patch_include_path },
+	];
 }
 
-sub install_perl_5100 {
-	my $self = shift;
-	$self->SUPER::install_perl_5100(@_);
-
-	# Install the vanilla CPAN::Config
-	$self->install_file(
-		share      => 'Perl-Dist-Strawberry CPAN_Config_5100.pm',
-		install_to => 'perl/lib/CPAN/Config.pm',
+sub install_perl_588_bin {
+	my $self   = shift;
+	my %params = @_;
+	my $patch  = delete($params{patch}) || [];
+	return $self->SUPER::install_perl_588_bin(
+		patch => [ qw{
+			win32/config.gc
+		}, @$patch ],
+		%params,
 	);
+}
 
-	return 1;
+sub install_perl_5100_bin {
+	my $self   = shift;
+	my %params = @_;
+	my $patch  = delete($params{patch}) || [];
+	return $self->SUPER::install_perl_5100_bin(
+		patch => [ qw{
+			win32/config.gc
+		}, @$patch ],
+		%params,
+	);
 }
 
 sub install_perl_modules {
 	my $self = shift;
 
-	# Install LWP::Online, so our custom minicpan code works
+	# Install LWP::Online so our custom minicpan code works
 	$self->install_distribution(
 		name => 'ADAMK/LWP-Online-1.07.tar.gz'
 	);
@@ -289,14 +338,12 @@ sub install_perl_modules {
 
 	# Install additional math modules
 	$self->install_pari;
-	$self->install_modules(qw{
+	$self->install_modules( qw{
 		Math::BigInt
 		Math::BigInt::FastCalc
 		Math::BigRat
-	});
-	$self->install_distribution(
-		name => 'TELS/math/Math-BigInt-GMP-1.24.tar.gz',
-	);
+		Math::BigInt::GMP
+	} );
 
 	# XML Modules
 	$self->install_distribution(
@@ -336,12 +383,6 @@ sub install_perl_modules {
 	);
 
 	# Console Utilities
-	$self->install_distribution(
-		# Latest version doesn't build, and pip needs it
-		# as a dependency.
-		name  => 'DCANTRELL/Data-Compare-1.19.tar.gz',
-		force => 1,
-	);
 	$self->install_modules( qw{
 		pler
 		pip
@@ -382,7 +423,7 @@ sub install_win32_extras {
 		);
 		$self->install_website(
 			name       => 'Strawberry Perl Website',
-			url        => 'http://strawberryperl.com/' . $self->output_base_filename,
+			url        => $self->strawberry_url,
 			icon_file  => 'Strawberry Perl Website.ico',
 		);
 	}
@@ -393,17 +434,31 @@ sub install_win32_extras {
 	return 1;
 }
 
+sub strawberry_url {
+	my $self = shift;
+	my $path = $self->output_base_filename;
+
+	# Strip off anything post-version
+	unless ( $path =~ s/^(strawberry-perl-\d+(?:\.\d+)+).*$/$1/ ) {
+		die("Failed to generate the strawberry subpath");
+	}
+
+	return "http://strawberryperl.com/$path";
+}
+
 
 
 
 
 #####################################################################
-# Installation Methods
+# Custom Installation Methods
 
 =pod
 
 =head2 install_patch
 
+  $dist->install_patch;
+
 The C<install_path> method can be used to install a copy of the Unix
 patch program into the distribution.
 
@@ -431,6 +486,63 @@ sub install_patch {
 	return 1;
 }
 
+=pod
+
+=head2 install_win32_manifest
+
+  $dist->install_win32_manifest( 'WX Perl' => 'perl', 'bin', 'wxperl.exe' );
+
+Installs a manifest file to make an executable binary look like a "real"
+Win32 program.
+
+=cut
+
+sub install_win32_manifest {
+	my $self = shift;
+	my $name = shift;
+
+	# Generate the file contents
+	my $manifest = <<"END_MANIFEST";
+<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
+ <assembly xmlns="urn:schemas-microsoft-com:asm.v1" manifestVersion="1.0">
+     <assemblyIdentity
+         processorArchitecture="x86"
+         version="5.1.0.0"
+         type="win32"
+         name="Controls"
+     />
+     <description>$name</description>
+     <dependency>
+         <dependentAssembly>
+             <assemblyIdentity
+                 type="win32"
+                 name="Microsoft.Windows.Common-Controls"        
+                 version="6.0.0.0"
+                 publicKeyToken="6595b64144ccf1df"
+                 language="*"
+                 processorArchitecture="x86"
+         />
+     </dependentAssembly>
+     </dependency>
+ </assembly>
+END_MANIFEST
+
+	# Write the manifest
+	my $file = File::Spec->catfile( $self->image_dir, @_ );
+	unless ( -f $file ) {
+		die "Program $file does not exist";
+	}
+
+	SCOPE: {
+		local *FILE;
+		open( FILE, '>', "$file.manifest" ) or die "open: $!";
+		print FILE $manifest                or die "print: $!";
+		close( FILE )                       or die "close: $!";
+	}
+
+	return 1;	
+}
+
 1;
 
 =pod
@@ -441,6 +553,10 @@ Bugs should be reported via the CPAN bug tracker at
 
 L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Perl-Dist-Strawberry>
 
+Please note that B<only> bugs in the distribution itself or the CPAN
+configuration should be reported to RT. Bugs in individual modules
+should be reported to their respective distributions.
+
 For more support information and places for discussion, see the
 Strawberry Perl Support page L<http://strawberryperl.com/support.html>.
 
